@@ -24,18 +24,18 @@ Multimedia::SDP::Generator - The SDP generator class
 
  my $generator = new Multimedia::SDP::Generator;
 
- $generator->v_field(0);
- $generator->o_field(
+ $generator->v(0);
+ $generator->o(
  	'username', 'session_id', 'session.version', 'IN', 'IP4', '127.0.0.1'
  );
- $generator->s_field('The name of my session');
- $generator->i_field('A short descrition of my session');
- $generator->u_field('http://url.to.my.session');
- $generator->e_field('someone@somewhere', 'Some One');
- $generator->c_field('IN', 'IP4', '127.0.0.1');
- $generator->t_field(time + (60 * 60 * 2)); # in two hours
- $generator->a_field('recvonly');
- $generator->m_field('audio', '49170', 'RTP/AVP', "0");
+ $generator->s('The name of my session');
+ $generator->i('A short descrition of my session');
+ $generator->u('http://url.to.my.session');
+ $generator->e('someone@somewhere', 'Some One');
+ $generator->c('IN', 'IP4', '127.0.0.1');
+ $generator->t(time + (60 * 60 * 2)); # in two hours
+ $generator->a('recvonly');
+ $generator->m('audio', '49170', 'RTP/AVP', "0");
 
  print $generator->output;
 
@@ -53,13 +53,11 @@ The following methods are available:
 use 5.005;
 use strict;
 use warnings;
-use vars qw(@EXPORT @EXPORT_OK %EXPORT_TAGS);
+use vars '@EXPORT';
 use base 'Exporter';
 use Multimedia::SDP::SinisterSdp;
 
-@EXPORT      = @Multimedia::SDP::SinisterSdp::EXPORT;
-@EXPORT_OK   = @Multimedia::SDP::SinisterSdp::EXPORT_OK;
-%EXPORT_TAGS = %Multimedia::SDP::SinisterSdp::EXPORT_TAGS;
+@EXPORT = @Multimedia::SDP::SinisterSdp::EXPORT;
 
 1;
 
@@ -70,12 +68,12 @@ __END__
 This is the constructor method; it creates a new B<Multimedia::SDP::Generator>
 object and returns a reference to it.
 
-=head2 v_field(VERSION)
+=head2 v(VERSION)
 
 This method generates a protocol version ("v") field. It takes a version number
 as its only argument.
 
-=head2 o_field(OWNER_OBJECT | USERNAME, SESSION_ID, SESSION_VERSION, NETWORK_TYPE, ADDRESS_TYPE, ADDRESS)
+=head2 o(OWNER_OBJECT | USERNAME, SESSION_ID, SESSION_VERSION, NETWORK_TYPE, ADDRESS_TYPE, ADDRESS)
 
 This function generates a session owner ("o") field, optionally from a
 B<Multimedia::SDP::Owner> object.
@@ -111,27 +109,27 @@ A string containing the IP address (e.g., "127.0.0.1").
 
 =back
 
-=head2 s_field(SESSION_NAME)
+=head2 s(SESSION_NAME)
 
 This method generates a session name ("s") field.
 
 It takes the session name as its only argument
 
-=head2 i_field(INFORMATION)
+=head2 i(INFORMATION)
 
 This function generates either a session information or media information ("s")
 field.
 
 It takes a short description of the session or media as its only argument.
 
-=head2 u_field(URI)
+=head2 u(URI)
 
 This method generates a URI ("u") field containing the URI of the session
 description.
 
 It takes a URI as its only argument.
 
-=head2 e_field(EMAIL_CONTACT_OBJECT | EMAIL_ADDRESS, NAME)
+=head2 e(EMAIL_CONTACT_OBJECT | EMAIL_ADDRESS, NAME)
 
 This method generates an email contact information ("e") field, optionally from
 a B<Multimedia::SDP::EmailContact> object.
@@ -152,7 +150,7 @@ that address.
 
 =back
 
-=head2 p_field(PHONE_CONTACT_OBJECT | PHONE_NUMBER, NAME)
+=head2 p(PHONE_CONTACT_OBJECT | PHONE_NUMBER, NAME)
 
 This method generates a telephone contact information ("p") field, optionally
 from a B<Multimedia::SDP::PhoneContact> object.
@@ -172,7 +170,7 @@ A string containing a phone number.
 
 =back
 
-=head2 c_field(CONNECTION_OBJECT | NETWORK_TYPE, ADDRESS_TYPE, ADDRESS, TTL, TOTAL_ADDRESSES)
+=head2 c(CONNECTION_OBJECT | NETWORK_TYPE, ADDRESS_TYPE, ADDRESS, TTL, TOTAL_ADDRESSES)
 
 This method generates a connection information ("c") field for the session or
 an individual media, optionally from a B<Multimedia::SDP::Connection> object.
@@ -205,7 +203,7 @@ I<ADDRESS>, how many addresses are available?
 
 =back
 
-=head2 b_field(BANDWIDTH_OBJECT | BANDWIDTH_MODIFIER, BANDWIDTH_VALUE)
+=head2 b(BANDWIDTH_OBJECT | BANDWIDTH_MODIFIER, BANDWIDTH_VALUE)
 
 This method generates a bandwidth information ("b") field, optionally from a
 B<Multimedia::SDP::Bandwidth> object.
@@ -226,7 +224,7 @@ A number that's the available bandwidth in kilobits per second.
 
 =back
 
-=head2 t_field(SESSION_PLAY_TIME_OBJECT | START_TIME, STOP_TIME)
+=head2 t(SESSION_PLAY_TIME_OBJECT | START_TIME, STOP_TIME)
 
 This method generates a session time ("t") field, optionally from a
 B<Multimedia::SDP::SessionPlayTime> object.
@@ -248,7 +246,7 @@ since epoch). This will be converted to an NTP timestamp.
 
 =back
 
-=head2 r_field(REPEAT_TIME_OBJECT | REPEAT_INTERVAL, ACTIVE_DURATION, REPEAT_OFFSETS)
+=head2 r(REPEAT_TIME_OBJECT | REPEAT_INTERVAL, ACTIVE_DURATION, REPEAT_OFFSETS)
 
 This method generates a repeat times ("r") field, optionally from a
 B<Multimedia::SDP::RepeatTime> object.
@@ -272,7 +270,7 @@ The repeat offsets, either as a reference to an array containing each offset as
 
 =back
 
-=head2 z_field(ZONE_ADJUSTMENT_OBJECTS | TIME, OFFSET, ...)
+=head2 z(ZONE_ADJUSTMENT_OBJECTS | TIME, OFFSET, ...)
 
 This method generates a time zone adjustment ("z") field.
 
@@ -292,7 +290,7 @@ hour).
 
 =back
 
-=head2 k_field(ENCRYPTION_OBJECT | METHOD, KEY)
+=head2 k(ENCRYPTION_OBJECT | METHOD, KEY)
 
 This method generates an encryption information ("k") field, optionally from a
 B<Multimedia::SDP::Encryption> object.
@@ -312,7 +310,7 @@ The encryption method (e.g., "PGP").
 
 =back
 
-=head2 a_field(ATTRIBUTE_OBJECT | NAME, VALUE)
+=head2 a(ATTRIBUTE_OBJECT | NAME, VALUE)
 
 This method generates a session attribute or media attribute ("a") field,
 optionally from a B<Multimedia::SDP::Attribute> object.
@@ -332,7 +330,7 @@ The attribute name.
 
 =back
 
-=head2 m_field(MEDIA_DESCRIPTION_OBJECT | MEDIA_TYPE, PORT, TOTAL_PORTS, TRANSPORT_PROTOCOL, FORMATS)
+=head2 m(MEDIA_DESCRIPTION_OBJECT | MEDIA_TYPE, PORT, TOTAL_PORTS, TRANSPORT_PROTOCOL, FORMATS)
 
 This method generates a media description ("m") field, and if you supply a
 B<Multimedia::SDP::MediaDescription> object, all other fields that go with it.
